@@ -187,7 +187,7 @@ Surv <- survival::Surv
 ns <- splines::ns
 
 
-#' Generate a Basis Matrix for Natural Cubic Splines
+#' B-Spline Basis for Polynomial Splines
 #'
 #' This function just calls \code{bs()} from the
 #' \href{https://CRAN.R-project.org/package=splines}{\strong{splines}}
@@ -196,7 +196,17 @@ ns <- splines::ns
 #' @inheritParams splines::bs
 #' @export
 #' @keywords internal
-bs <- splines::bs
+# bs <- splines::bs
+
+bs <- function(x, df = NULL, knots = NULL, degree = 3, intercept = FALSE,
+               Boundary.knots = range(x), warn.outside = TRUE) {
+
+  defargs <- formals(splines::bs)
+  args <- sapply(names(defargs), function(k)
+    get(k), simplify = FALSE)
+
+  do.call(splines::bs, args)
+}
 
 
 
